SystemOrganization addCategory: #'Smutty-Web'!

Object subclass: #GraphRenderer
	instanceVariableNames: 'graph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Smutty-Web'!

!GraphRenderer commentStamp: 'SergioFedi 8/24/2015 07:06' prior: 0!
I render a graph.
!

GraphRenderer subclass: #GraphHtmlRenderer
	instanceVariableNames: 'filesystem outputDirectory htmlName enumeratedNodes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Smutty-Web'!

!GraphHtmlRenderer commentStamp: 'SergioFedi 8/24/2015 07:06' prior: 0!
I render a graph in HTML!

!GraphHtmlRenderer methodsFor: 'public' stamp: 'SergioFedi 9/9/2015 08:27'!
enumerateNodes

	| nodes firstNode |
	enumeratedNodes := Dictionary new.
	nodes := LinkedList newFrom: self graph nodes.
	firstNode := self firstNodeFrom: self graph.
	nodes remove: firstNode.
	nodes addFirst: firstNode.
	nodes
		with: (1 to: self graph nodesSize)
		do: [:node :index |
			enumeratedNodes at: node put: index.
		].
! !

!GraphHtmlRenderer methodsFor: 'accessors' stamp: 'SergioFedi 8/24/2015 07:09'!
filesystem
	filesystem isNil ifTrue: [ filesystem := FileSystem workingDirectory ].
	^ filesystem! !

!GraphHtmlRenderer methodsFor: 'accessors' stamp: 'SergioFedi 8/24/2015 07:09'!
filesystem: aFileSystem 
	filesystem := aFileSystem.! !

!GraphHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 9/9/2015 07:44'!
firstNodeFrom: aGraph

	self subclassResponsibility.! !

!GraphHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 8/25/2015 08:19'!
htmlFileContentsForNode: aGraphNode withTransitions: transitions

	^WAHtmlCanvas builder 
	fullDocument: false;
	render: [ :html |
		self renderNode: aGraphNode from: self graph on: html]! !

!GraphHtmlRenderer methodsFor: 'accessors' stamp: 'SergioFedi 8/24/2015 07:13'!
htmlName: aString 
	htmlName := aString .! !

!GraphHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 8/24/2015 07:41'!
mainHtmlFileContents

	| doc ctx root html |
	^String streamContents: [ :stream |
	    doc := WAHtmlDocument on: stream.
	    ctx := WARenderContext new document: doc.
	    root := WAHtmlRoot new.
		 root setContext: ctx.
	    self rootBlock value: root.
	    root writeHeadOn: doc.
	    html := WAHtmlCanvas new initializeWithContext: ctx.
	    self renderBlock value: html.
	    root writeFootOn: doc ].
! !

!GraphHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 8/24/2015 07:47'!
mainStoryDivId
	^ 'mainStoryNode'! !

!GraphHtmlRenderer methodsFor: 'accessing' stamp: 'SergioFedi 8/24/2015 07:13'!
outputDirectory
	^ outputDirectory! !

!GraphHtmlRenderer methodsFor: 'accessors' stamp: 'SergioFedi 8/24/2015 07:12'!
outputDirectory: aString 
	outputDirectory := aString.! !

!GraphHtmlRenderer methodsFor: 'public' stamp: 'SergioFedi 8/24/2015 07:22'!
render

	filesystem ensureCreateDirectory: self outputDirectory.
	self enumerateNodes.
	self renderMainHtmlFile.
	self renderStoryNodes.! !

!GraphHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 8/24/2015 07:48'!
renderBlock
	^ [ :html | 
	html div 
		class: 'container';
		with:
		[	html heading level1 with: 'Story Map'.
			html div
				id: self mainStoryDivId;
				class: 'storyNode';
				with: [ :html2 | self renderFirstNodeFrom: self graph on: html2 ].
			html script with: 'function onLoad(){
				installNavigationFunctionality();
			};'.
		]
	].
! !

!GraphHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 9/9/2015 07:41'!
renderFirstNodeFrom: aGraph on: html

	self renderNode: (self firstNodeFrom: aGraph) from: aGraph on: html! !

!GraphHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 8/24/2015 07:24'!
renderMainHtmlFile

	| htmlFile |
	htmlFile := filesystem writeStreamOn: self outputDirectory, filesystem separator asString, htmlName, '.html'.
	htmlFile nextPutAll: self mainHtmlFileContents.
	htmlFile close.! !

!GraphHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 8/24/2015 07:47'!
renderScriptsOn: root

	root script
		url: 'lib/jquery-1.11.2.min.js'.
	root script
		url: 'lib/smuttyFunctions.js'.
	"root addScript: 'function onLoad(){
		installNavigationFunctionality();
	};'."
! !

!GraphHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 8/25/2015 08:16'!
renderStoryNodes

	enumeratedNodes associationsDo: 
		[:association |
			| htmlFile node index |
			node := association key.
			index := association value.
			
			htmlFile := filesystem writeStreamOn:
				self outputDirectory, 
				filesystem separator asString, 
				htmlName, 
				('_node_{1}.html' format: index asOrderedCollection).
			htmlFile nextPutAll: (self htmlFileContentsForNode: node withTransitions: (self graph transitionsFrom: node)).
			htmlFile close.
		].! !

!GraphHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 8/24/2015 07:46'!
rootBlock
	^ [ :root | 
	root
		title: self title;
		beHtml5.
	root stylesheet url: 'css/testStory.css'.
	root meta charset: 'utf-8'.
	self renderScriptsOn: root ]! !

GraphHtmlRenderer subclass: #SJTRenderer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Smutty-Web'!

!SJTRenderer commentStamp: 'SergioFedi 9/11/2015 06:19' prior: 0!
I know how to render an interface over an SJTGame.!

!SJTRenderer methodsFor: 'private' stamp: 'SergioFedi 9/9/2015 07:39'!
firstNodeFrom: aGameStateGraph
	^ aGameStateGraph initialNode! !

!SJTRenderer methodsFor: 'private' stamp: 'SergioFedi 8/31/2015 10:32'!
renderNode: aGameStateNode from: aGameStateGraph on: html 
	
	| transitions interface |
	interface := SJTGameController on: (aGameStateNode newGame).
	transitions := interface options.
	html div
		class: 'locationName';
		with: [
			html paragraph with: (interface locationName).
		].
	html div
		class: 'locationDescription';
		with: [
			html paragraph with: (interface locationDescription).
		].
	html div
		class: 'options';
		with: [
			(aGameStateGraph transitionsFrom: aGameStateNode) do: [:transition | 
				| anchor  htmlNodeName |
				anchor := html anchor.
				htmlNodeName := htmlName, '_node_', (enumeratedNodes at: transition destination) asString, '.html'.
				anchor class: 'action'.
				anchor attributes at: 'htmlReference' put: htmlNodeName.
				anchor with: transition action description.
			]
		].! !

!SJTRenderer methodsFor: 'private' stamp: 'SergioFedi 8/24/2015 07:47'!
title
	^ 'SJT (Locations) Render'! !

SJTRenderer subclass: #SJTRendererDraft01
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Smutty-Web'!

!SJTRendererDraft01 commentStamp: 'SergioFedi 9/11/2015 06:32' prior: 0!
I render the first draft of the SJTGame interface.

Its mostly functional, no graphics.
The options are buttons.

!

SJTRenderer subclass: #SJTRendererDraft02
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Smutty-Web'!

!SJTRendererDraft02 commentStamp: 'SergioFedi 9/11/2015 06:31' prior: 0!
I render the second draft of the SJTGame interface.

Its mostly functional, no graphics.
It differentiates between movement options and interacting options.
The options are a line of text instead of buttons.
!

!SJTRendererDraft02 methodsFor: 'private' stamp: 'SergioFedi 9/29/2015 07:40'!
actionSubtypeForTransition: aGameTransition

	| answer |
	(aGameTransition action class = FinishDialog) ifTrue: [answer := 'ender'].
	(aGameTransition action class = InteractWithNPC) ifTrue: [answer := 'opener'].
	^answer.
	.! !

!SJTRendererDraft02 methodsFor: 'private' stamp: 'SergioFedi 9/29/2015 07:41'!
actionTypeForTransition: aGameTransition

	| answer |
	(aGameTransition action class = MoveAction) ifTrue: [answer := 'movement'].
	(aGameTransition action class = FinishDialog) ifTrue: [answer := 'interaction'].
	(aGameTransition action class = InteractWithNPC) ifTrue: [answer := 'interaction'].
	(aGameTransition action class = ChooseDialogOption) ifTrue: [answer := 'interaction'].
	answer isNil ifTrue: [
		"Error: we don't have a mapping between the type of transition and the actionType HTML attribute of the list item"
		self halt.].
	^answer.
	! !

!SJTRendererDraft02 methodsFor: 'private' stamp: 'SergioFedi 9/29/2015 07:32'!
addActionTypesTo: aTag forTransition: aGameTransition

	| subType |
	aTag attributeAt: 'actionType' put: (self actionTypeForTransition: aGameTransition).
	subType := (self actionSubtypeForTransition: aGameTransition).
	subType notNil ifTrue: [
		aTag attributeAt: 'actionSubtype' put: subType.
	].! !

!SJTRendererDraft02 methodsFor: 'as yet unclassified' stamp: 'SergioFedi 9/29/2015 06:38'!
renderBlock
	^ [ :html | 
	html div 
		class: 'container';
		with:
		[	
			html div
				id: self mainStoryDivId;
				class: 'storyNode';
				with: [ :html2 | self renderFirstNodeFrom: self graph on: html2 ].
			html script with: 'function onLoad(){
				installNavigationFunctionality();
			};'.
		]
	].! !

!SJTRendererDraft02 methodsFor: 'as yet unclassified' stamp: 'FedericoFigueredo 9/10/2015 07:21'!
renderMainHtmlFile! !

!SJTRendererDraft02 methodsFor: 'as yet unclassified' stamp: 'SergioFedi 9/29/2015 07:27'!
renderNode: aGameStateNode from: aGameStateGraph on: html 
	
	| transitions interface |
	interface := SJTGameController on: (aGameStateNode newGame).
	transitions := interface options.
	html heading level2
		class: 'locationName';
		with: [
			html text: interface locationName.
		].
	html paragraph
		class: 'locationDescription';
		with: [
			html text: (interface locationDescription).
		].
	html unorderedList 
		class: 'optionList locationActions';
		with: [
			(aGameStateGraph transitionsFrom: aGameStateNode) do: [:transition | 
				| htmlNodeName listItem |
				
				htmlNodeName := htmlName, '_node_', (enumeratedNodes at: transition destination) asString, '.html'.
				listItem := html listItem.
				self addActionTypesTo: listItem forTransition: transition.
				listItem
					attributeAt: 'htmlReference' put: htmlNodeName;
					with: [ 
						html paragraph 
							with: transition action description].
			]
		].! !

!SJTRendererDraft02 methodsFor: 'as yet unclassified' stamp: 'SergioFedi 9/29/2015 06:48'!
title
	^ 'SJT (Locations & NPCs) Render'! !

GraphHtmlRenderer subclass: #StoryMapHtmlRenderer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Smutty-Web'!

!StoryMapHtmlRenderer commentStamp: 'SergioFedi 6/5/2015 23:33' prior: 0!
I render a StoryMap in several files.
Among these files there will be a main html file which you can browse statically to navigate the StoryMap.!

!StoryMapHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 9/9/2015 07:39'!
firstNodeFrom: aStoryMap
	^ aStoryMap beginning! !

!StoryMapHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 6/18/2015 06:47'!
renderNode: aStoryNode from: aStoryMap on: html 
	
	| transitions |
	transitions := aStoryMap transitionsFrom: aStoryNode.
	html div
		class: 'nodeText';
		with: [
			aStoryNode paragraphs do: [:paragraph |
				html paragraph with: paragraph.
			]
		].
	html div
		class: 'actions';
		with: [
			transitions do: [:transition | 
				| anchor  htmlNodeName |
				anchor := html anchor.
				htmlNodeName := htmlName, '_node_', (enumeratedNodes at: transition destination) asString, '.html'.
				anchor class: 'action'.
				anchor attributes at: 'htmlReference' put: htmlNodeName.
				anchor with: transition actionDescription.
			]
		].! !

!StoryMapHtmlRenderer methodsFor: 'accessing' stamp: 'SergioFedi 8/18/2015 07:28'!
storyMap
	^self graph! !

!StoryMapHtmlRenderer methodsFor: 'accessors' stamp: 'SergioFedi 8/18/2015 07:25'!
storyMap: aStoryMap 
	self graph: aStoryMap.! !

!StoryMapHtmlRenderer methodsFor: 'private' stamp: 'SergioFedi 8/24/2015 07:46'!
title
	^ 'Story Map Render'! !

!GraphRenderer methodsFor: 'accessing' stamp: 'SergioFedi 8/18/2015 07:24'!
graph
	^ graph! !

!GraphRenderer methodsFor: 'accessing' stamp: 'SergioFedi 8/18/2015 07:24'!
graph: anObject
	graph := anObject! !

!GraphRenderer methodsFor: 'as yet unclassified' stamp: 'SergioFedi 8/18/2015 07:22'!
render

	self subclassResponsibility.! !

GraphRenderer subclass: #StoryMapMarkdownRenderer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Smutty-Web'!

!StoryMapMarkdownRenderer commentStamp: 'SergioFedi 8/18/2015 07:19' prior: 0!
I render a StoryMap in a single file.
This is a render in markdown syntax.!

!StoryMapMarkdownRenderer class methodsFor: 'instance creation' stamp: 'FedericoFigueredo 6/18/2015 08:06'!
on: aStoryMap 
	^ self new storyMap: aStoryMap.! !

!StoryMapMarkdownRenderer methodsFor: 'public' stamp: 'SergioFedi 8/18/2015 07:26'!
render
	| stream nodes |
	stream := WriteStream on: String new.
	nodes := self storyMap nodes.
	
	nodes do: 
		[ :node | stream 
		nextPutAll: '# Name', (nodes indexOf: node) asString;
		cr;
		nextPutAll: node text;
		cr.
		(self storyMap transitionsFrom: node) do: [ :transition | stream 
			cr;
			nextPut: $[; 
			nextPutAll: transition actionDescription;
			nextPut: $];
			nextPut: $(;
			nextPutAll: 'Name', (nodes indexOf: transition destination) asString;
			"Después hacemos algo tipo | nextPutAll: transition destination name;"
			nextPut: $);
			yourself.]
		]
		separatedBy: [ stream cr; cr ].
		
	^ stream contents.! !

!StoryMapMarkdownRenderer methodsFor: 'accessing' stamp: 'SergioFedi 8/18/2015 07:28'!
storyMap
	^self graph.! !

!StoryMapMarkdownRenderer methodsFor: 'accessors' stamp: 'SergioFedi 8/18/2015 07:25'!
storyMap: aStoryMap

	self graph: aStoryMap.! !

WAComponent subclass: #SmuttyWebApp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Smutty-Web'!

!SmuttyWebApp methodsFor: 'as yet unclassified' stamp: 'FedericoFigueredo 6/16/2015 07:51'!
renderContentOn: html
	html heading with: 'Hola Manola'.! !

WASession subclass: #SmuttySession
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Smutty-Web'!

WAFileLibrary subclass: #SmuttyLibrary
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Smutty-Web'!
